/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.logging.ri.log4j;

import org.jdtaus.core.container.ContainerInitializer;
import org.jdtaus.core.container.Dependency;
import org.jdtaus.core.container.Implementation;
import org.jdtaus.core.container.ModelFactory;
import org.jdtaus.core.container.Property;
import org.jdtaus.core.container.PropertyException;
import org.jdtaus.core.logging.spi.Logger;

/**
 * jDTAUS Core SPI Log4J {@code Logger} implementation.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: Log4JLogger.java 2542 2007-04-12 10:06:29Z schulte2005 $
 */
public class Log4JLogger implements ContainerInitializer, Logger
{

    //--Implementation----------------------------------------------------------

    // This section is generated by jdtaus-source-plugin.

    /** Meta-data describing the implementation. */
    private static final Implementation META =
        ModelFactory.getModel().getModules().
        getImplementation(Log4JLogger.class.getName());

    //----------------------------------------------------------Implementation--
    //--Constructors------------------------------------------------------------

    // This section is generated by jdtaus-source-plugin.

    /** Protected <code>Log4JLogger</code> implementation constructor.
    * @param meta Implementation meta-data.
    */
    protected Log4JLogger(final Implementation meta)
    {
        super();
        Property p;

        p = meta.getProperties().getProperty("name");
        this._name = (java.lang.String) p.getValue();

    }
    /** Protected <code>Log4JLogger</code> dependency constructor.
    * @param meta Dependency meta-data.
    */
    protected Log4JLogger(final Dependency meta)
    {
        super();
        Property p;

        p = meta.getProperties().getProperty("name");
        this._name = (java.lang.String) p.getValue();

    }

    //------------------------------------------------------------Constructors--
    //--ContainerInitializer----------------------------------------------------

    /** Log4J logger. */
    private org.apache.log4j.Logger logger;

    public void initialize()
    {
        this.assertValidProperties();
        this.logger = org.apache.log4j.Logger.getLogger(this.getName());
    }

    //----------------------------------------------------ContainerInitializer--
    //--Properties--------------------------------------------------------------

    // This section is generated by jdtaus-source-plugin.

    /**
     * Property {@code name}.
     * @serial
     */
    private java.lang.String _name;

    /** <code>name</code> property getter. */
    protected java.lang.String getName()
    {
        return this._name;
    }


    //--------------------------------------------------------------Properties--
    //--Logger------------------------------------------------------------------

    public boolean isDebugEnabled()
    {
        return this.logger.isEnabledFor(org.apache.log4j.Level.DEBUG);
    }

    public void debug(String string)
    {
        this.logger.debug(string);
    }

    public void debug(Throwable throwable)
    {
        this.logger.debug(throwable.getMessage(), throwable);
    }

    public boolean isErrorEnabled()
    {
        return this.logger.isEnabledFor(org.apache.log4j.Level.ERROR);
    }

    public void error(String string)
    {
        this.logger.error(string);
    }

    public void error(Throwable throwable)
    {
        this.logger.error(throwable.getMessage(), throwable);
    }

    public boolean isFatalEnabled()
    {
        return this.logger.isEnabledFor(org.apache.log4j.Level.FATAL);
    }

    public void fatal(String string)
    {
        this.logger.fatal(string);
    }

    public void fatal(Throwable throwable)
    {
        this.logger.fatal(throwable.getMessage(), throwable);
    }

    public boolean isInfoEnabled()
    {
        return this.logger.isEnabledFor(org.apache.log4j.Level.INFO);
    }

    public void info(String string)
    {
        this.logger.info(string);
    }

    public void info(Throwable throwable)
    {
        this.logger.info(throwable.getMessage(), throwable);
    }

    public boolean isTraceEnabled()
    {
        return this.logger.isEnabledFor(org.apache.log4j.Level.TRACE);
    }

    public void trace(String string)
    {
        this.logger.trace(string);
    }

    public void trace(Throwable throwable)
    {
        this.logger.trace(throwable.getMessage(), throwable);
    }

    public boolean isWarnEnabled()
    {
        return this.logger.isEnabledFor(org.apache.log4j.Level.WARN);
    }

    public void warn(String string)
    {
        this.logger.warn(string);
    }

    public void warn(Throwable throwable)
    {
        this.logger.warn(throwable.getMessage(), throwable);
    }

    //------------------------------------------------------------------Logger--
    //--Log4JLogger-------------------------------------------------------------

    /** Creates a new {@code Log4JLogger} instance. */
    public Log4JLogger()
    {
        this(Log4JLogger.META);
        this.initialize();
    }

    /**
     * Checks configured properties.
     *
     * @throws PropertyException if property {@code name} is {@code null} or
     * of no length.
     */
    protected void assertValidProperties()
    {
        if(this.getName() == null || this.getName().length() <= 0)
        {
            throw new PropertyException("name", this.getName());
        }
    }

    //-------------------------------------------------------------Log4JLogger--

}
